.card {
    box-shadow: rgba(0, 0, 0, 0.1) 0 0.25rem 0.375rem -0.0625rem, rgba(0, 0, 0, 0.06) 0 0.125rem 0.25rem -0.0625rem !important;
    border-width: 1px;
    border-color: var(--bs-border-color);
}

.card-body {
    background-color: var(--bs-card-bg);
}
